@@ -228,7 +228,7 @@ pub struct GeneralConfig {
     pub enable_recover_mode: bool,
 
     #[serde(default)]
-    pub cursor: UiElement,
+    pub hide_remaps_in_help_menu: bool,
 
     #[serde(default)]
     pub prompt: UiElement,
@@ -282,11 +282,29 @@ pub struct KeyBindings {
     #[serde(default)]
     pub on_number: Option<Action>,
 
+    #[serde(default)]
+    pub on_alphanumeric: Option<Action>,
+
     #[serde(default)]
     pub on_special_character: Option<Action>,
 
+    #[serde(default)]
+    pub on_character: Option<Action>,
+
+    #[serde(default)]
+    pub on_navigation: Option<Action>,
+
+    #[serde(default)]
+    pub on_function: Option<Action>,
+
     #[serde(default)]
     pub default: Option<Action>,
+    // Checklist for adding field:
+    // - [ ] Update App::handle_key
+    // - [ ] Update KeyBindings::sanitized
+    // - [ ] Update Mode::help_menu
+    // - [ ] Update configure-key-bindings.md
+    // - [ ] Update debug-key-bindings.md
 }
 
 impl KeyBindings {
@@ -298,14 +316,23 @@ impl KeyBindings {
                 .filter_map(|(k, a)| a.sanitized(read_only).map(|a| (k, a)))
                 .collect();
 
-            self.on_alphabet = self.on_alphabet.and_then(|a| a.sanitized(read_only));
-            self.on_number = self.on_number.and_then(|a| a.sanitized(read_only));
+            self.on_alphabet =
+                self.on_alphabet.and_then(|a| a.sanitized(read_only));
+            self.on_number =
+                self.on_number.and_then(|a| a.sanitized(read_only));
+            self.on_alphanumeric =
+                self.on_alphanumeric.and_then(|a| a.sanitized(read_only));
             self.on_special_character = self
                 .on_special_character
                 .and_then(|a| a.sanitized(read_only));
+            self.on_character =
+                self.on_character.and_then(|a| a.sanitized(read_only));
+            self.on_navigation =
+                self.on_navigation.and_then(|a| a.sanitized(read_only));
+            self.on_function =
+                self.on_function.and_then(|a| a.sanitized(read_only));
             self.default = self.default.and_then(|a| a.sanitized(read_only));
         };
-
         self
     }
 }
@@ -353,32 +380,36 @@ impl Mode {
                 let lines = extra_help_lines
                     .unwrap_or_default()
                     .into_iter()
-                    .chain(self.key_bindings.on_key.iter().filter_map(|(k, a)| {
-                        let remaps = self
-                            .key_bindings
-                            .on_key
-                            .iter()
-                            .filter_map(|(rk, ra)| {
-                                if rk == k {
-                                    None
-                                } else if a == ra {
-                                    Some(rk.clone())
-                                } else {
-                                    None
-                                }
+                    .chain(self.key_bindings.on_key.iter().filter_map(
+                        |(k, a)| {
+                            let remaps = self
+                                .key_bindings
+                                .on_key
+                                .iter()
+                                .filter_map(|(rk, ra)| {
+                                    if rk == k {
+                                        None
+                                    } else if a == ra {
+                                        Some(rk.clone())
+                                    } else {
+                                        None
+                                    }
+                                })
+                                .collect::<Vec<String>>();
+                            a.help.clone().map(|h| {
+                                HelpMenuLine::KeyMap(k.into(), remaps, h)
                             })
-                            .collect::<Vec<String>>();
-                        a.help
-                            .clone()
-                            .map(|h| HelpMenuLine::KeyMap(k.into(), remaps, h))
-                    }))
+                        },
+                    ))
                     .chain(
                         self.key_bindings
                             .on_alphabet
                             .iter()
                             .map(|a| ("[a-Z]", a.help.clone()))
                             .filter_map(|(k, mh)| {
-                                mh.map(|h| HelpMenuLine::KeyMap(k.into(), vec![], h))
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
                             }),
                     )
                     .chain(
@@ -387,16 +418,64 @@ impl Mode {
                             .iter()
                             .map(|a| ("[0-9]", a.help.clone()))
                             .filter_map(|(k, mh)| {
-                                mh.map(|h| HelpMenuLine::KeyMap(k.into(), vec![], h))
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
+                            }),
+                    )
+                    .chain(
+                        self.key_bindings
+                            .on_alphanumeric
+                            .iter()
+                            .map(|a| ("[0-Z]", a.help.clone()))
+                            .filter_map(|(k, mh)| {
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
                             }),
                     )
                     .chain(
                         self.key_bindings
                             .on_special_character
                             .iter()
-                            .map(|a| ("[spcl chars]", a.help.clone()))
+                            .map(|a| ("[^0-Z]", a.help.clone()))
                             .filter_map(|(k, mh)| {
-                                mh.map(|h| HelpMenuLine::KeyMap(k.into(), vec![], h))
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
+                            }),
+                    )
+                    .chain(
+                        self.key_bindings
+                            .on_character
+                            .iter()
+                            .map(|a| ("[*]", a.help.clone()))
+                            .filter_map(|(k, mh)| {
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
+                            }),
+                    )
+                    .chain(
+                        self.key_bindings
+                            .on_navigation
+                            .iter()
+                            .map(|a| ("[nav]", a.help.clone()))
+                            .filter_map(|(k, mh)| {
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
+                            }),
+                    )
+                    .chain(
+                        self.key_bindings
+                            .on_function
+                            .iter()
+                            .map(|a| ("[f1-f12]", a.help.clone()))
+                            .filter_map(|(k, mh)| {
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
                             }),
                     )
                     .chain(
@@ -405,7 +484,9 @@ impl Mode {
                             .iter()
                             .map(|a| ("[default]", a.help.clone()))
                             .filter_map(|(k, mh)| {
-                                mh.map(|h| HelpMenuLine::KeyMap(k.into(), vec![], h))
+                                mh.map(|h| {
+                                    HelpMenuLine::KeyMap(k.into(), vec![], h)
+                                })
                             }),
                     );
 
@@ -414,7 +495,9 @@ impl Mode {
 
                 for line in lines {
                     match line {
-                        HelpMenuLine::Paragraph(p) => result.push(HelpMenuLine::Paragraph(p)),
+                        HelpMenuLine::Paragraph(p) => {
+                            result.push(HelpMenuLine::Paragraph(p))
+                        }
                         HelpMenuLine::KeyMap(k, r, d) => {
                             if !remapped.contains(&k) {
                                 for k in r.iter() {
@@ -510,10 +593,18 @@ impl BuiltinModesConfig {
             "search" => Some(&self.search),
             "sort" => Some(&self.sort),
             "filter" => Some(&self.filter),
-            "relative_path_does_contain" => Some(&self.relative_path_does_contain),
-            "relative path does contain" => Some(&self.relative_path_does_contain),
-            "relative_path_does_not_contain" => Some(&self.relative_path_does_not_contain),
-            "relative path does not contain" => Some(&self.relative_path_does_not_contain),
+            "relative_path_does_contain" => {
+                Some(&self.relative_path_does_contain)
+            }
+            "relative path does contain" => {
+                Some(&self.relative_path_does_contain)
+            }
+            "relative_path_does_not_contain" => {
+                Some(&self.relative_path_does_not_contain)
+            }
+            "relative path does not contain" => {
+                Some(&self.relative_path_does_not_contain)
+            }
             "switch layout" => Some(&self.switch_layout),
             "switch_layout" => Some(&self.switch_layout),
             "quit" => Some(&self.quit),
