@@ -14,11 +14,14 @@ xplr.config.general.show_hidden = false
 xplr.config.general.read_only = false
 
 ------ Recover mode
-xplr.config.general.disable_recover_mode = false
+xplr.config.general.enable_recover_mode = false
 
 ------ Start FIFO
 xplr.config.general.start_fifo = nil
 
+------ Hide remaps in help menu
+xplr.config.general.hide_remaps_in_help_menu = false
+
 ------ Prompt
 xplr.config.general.prompt.format = "❯ "
 xplr.config.general.prompt.style.add_modifiers = nil
@@ -26,13 +29,6 @@ xplr.config.general.prompt.style.sub_modifiers = nil
 xplr.config.general.prompt.style.bg = nil
 xplr.config.general.prompt.style.fg = nil
 
------- Cursor
-xplr.config.general.cursor.format = "█"
-xplr.config.general.cursor.style.add_modifiers = nil
-xplr.config.general.cursor.style.bg = nil
-xplr.config.general.cursor.style.fg = nil
-xplr.config.general.cursor.style.sub_modifiers = nil
-
 ------ Initial layout
 xplr.config.general.initial_layout = "default"
 
@@ -98,6 +94,14 @@ xplr.config.general.selection_ui.style.sub_modifiers = nil
 xplr.config.general.selection_ui.style.bg = nil
 xplr.config.general.selection_ui.style.fg = "LightGreen"
 
+------ Focus UI
+xplr.config.general.focus_selection_ui.prefix = "▸["
+xplr.config.general.focus_selection_ui.suffix = "]"
+xplr.config.general.focus_selection_ui.style.add_modifiers = { "Bold" }
+xplr.config.general.focus_selection_ui.style.sub_modifiers = nil
+xplr.config.general.focus_selection_ui.style.bg = nil
+xplr.config.general.focus_selection_ui.style.fg = "LightGreen"
+
 ------ Sort & filter UI
 -------- Separator
 xplr.config.general.sort_and_filter_ui.separator.format = " › "
@@ -948,7 +952,6 @@ xplr.config.modes.builtin.default = {
         },
       },
     },
-    on_alphabet = nil,
     on_number = {
       help = "input",
       messages = {
@@ -957,8 +960,6 @@ xplr.config.modes.builtin.default = {
         "BufferInputFromKey",
       },
     },
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -989,8 +990,22 @@ xplr.config.modes.builtin.default.key_bindings.on_key["l"] =
 ------ Recover
 xplr.config.modes.builtin.recover = {
   name = "recover",
-  help = nil,
-  extra_help = nil,
+  layout = {
+    CustomContent = {
+      title = " recover ",
+      body = {
+        StaticParagraph = {
+          render = [[
+
+  You pressed an invalid key and went into "recover" mode.
+  This mode saves you from performing unwanted actions.
+
+  Let's calm down, press `escape`, and try again.
+          ]],
+        },
+      },
+    },
+  },
   key_bindings = {
     on_key = {
       ["ctrl-c"] = {
@@ -1002,11 +1017,7 @@ xplr.config.modes.builtin.recover = {
         messages = { "PopMode" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
     default = {
-      help = nil,
       messages = {},
     },
   },
@@ -1091,10 +1102,6 @@ xplr.config.modes.builtin.selection_ops = {
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1138,10 +1145,6 @@ xplr.config.modes.builtin.create = {
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1152,26 +1155,10 @@ xplr.config.modes.builtin.create_directory = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = { "RemoveInputBufferLastCharacter" },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            SetInputBuffer = "",
-          },
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = { "RemoveInputBufferLastWord" },
-      },
       enter = {
         help = "create directory",
         messages = {
@@ -1196,12 +1183,8 @@ xplr.config.modes.builtin.create_directory = {
         messages = { "PopMode" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
     default = {
-      help = nil,
-      messages = { "BufferInputFromKey" },
+      messages = { "UpdateInputBufferFromKey" },
     },
   },
 }
@@ -1213,26 +1196,10 @@ xplr.config.modes.builtin.create_file = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = { "RemoveInputBufferLastCharacter" },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            SetInputBuffer = "",
-          },
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = { "RemoveInputBufferLastWord" },
-      },
       enter = {
         help = "create file",
         messages = {
@@ -1257,12 +1224,9 @@ xplr.config.modes.builtin.create_file = {
         messages = { "PopMode" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
     on_special_character = nil,
     default = {
-      help = nil,
-      messages = { "BufferInputFromKey" },
+      messages = { "UpdateInputBufferFromKey" },
     },
   },
 }
@@ -1274,26 +1238,10 @@ xplr.config.modes.builtin.number = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = { "RemoveInputBufferLastCharacter" },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            SetInputBuffer = "",
-          },
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = { "RemoveInputBufferLastWord" },
-      },
       down = {
         help = "to down",
         messages = { "FocusNextByRelativeIndexFromInput", "PopMode" },
@@ -1311,13 +1259,13 @@ xplr.config.modes.builtin.number = {
         messages = { "FocusPreviousByRelativeIndexFromInput", "PopMode" },
       },
     },
-    on_alphabet = nil,
+    on_navigation = {
+      messages = { "UpdateInputBufferFromKey" },
+    },
     on_number = {
       help = "input",
-      messages = { "BufferInputFromKey" },
+      messages = { "UpdateInputBufferFromKey" },
     },
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1372,10 +1320,6 @@ xplr.config.modes.builtin.go_to = {
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1386,26 +1330,10 @@ xplr.config.modes.builtin.rename = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = { "RemoveInputBufferLastCharacter" },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            SetInputBuffer = "",
-          },
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = { "RemoveInputBufferLastWord" },
-      },
       enter = {
         help = "rename",
         messages = {
@@ -1427,12 +1355,9 @@ xplr.config.modes.builtin.rename = {
         messages = { "PopMode" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
     default = {
       help = nil,
-      messages = { "BufferInputFromKey" },
+      messages = { "UpdateInputBufferFromKey" },
     },
   },
 }
@@ -1499,10 +1424,6 @@ xplr.config.modes.builtin.delete = {
         messages = { "PopMode" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1590,7 +1511,6 @@ xplr.config.modes.builtin.action = {
         },
       },
     },
-    on_alphabet = nil,
     on_number = {
       help = "go to index",
       messages = {
@@ -1601,8 +1521,6 @@ xplr.config.modes.builtin.action = {
         "BufferInputFromKey",
       },
     },
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1666,51 +1584,10 @@ xplr.config.modes.builtin.search = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "RemoveInputBufferLastCharacter",
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          {
-            SetInputBuffer = "",
-          },
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "RemoveInputBufferLastWord",
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       down = {
         help = "down",
         messages = { "FocusNext" },
@@ -1725,19 +1602,6 @@ xplr.config.modes.builtin.search = {
           "ExplorePwdAsync",
         },
       },
-      left = {
-        help = "back",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "Back",
-          {
-            SetInputBuffer = "",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       right = {
         help = "enter",
         messages = {
@@ -1751,6 +1615,19 @@ xplr.config.modes.builtin.search = {
           "ExplorePwdAsync",
         },
       },
+      left = {
+        help = "back",
+        messages = {
+          {
+            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
+          },
+          "Back",
+          {
+            SetInputBuffer = "",
+          },
+          "ExplorePwdAsync",
+        },
+      },
       tab = {
         help = "toggle selection",
         messages = { "ToggleSelection", "FocusNext" },
@@ -1760,16 +1637,12 @@ xplr.config.modes.builtin.search = {
         messages = { "FocusPrevious" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
     default = {
-      help = nil,
       messages = {
         {
           RemoveNodeFilterFromInput = "IRelativePathDoesContain",
         },
-        "BufferInputFromKey",
+        "UpdateInputBufferFromKey",
         {
           AddNodeFilterFromInput = "IRelativePathDoesContain",
         },
@@ -1808,10 +1681,6 @@ xplr.config.modes.builtin.filter = {
           "ExplorePwdAsync",
         },
       },
-      backspace = {
-        help = "remove last filter",
-        messages = { "RemoveLastNodeFilter", "ExplorePwdAsync" },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
@@ -1844,10 +1713,6 @@ xplr.config.modes.builtin.filter = {
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -1861,51 +1726,10 @@ xplr.config.modes.builtin.relative_path_does_contain = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "RemoveInputBufferLastCharacter",
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          {
-            SetInputBuffer = "",
-          },
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "RemoveInputBufferLastWord",
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       enter = {
         help = "apply filter",
         messages = { "PopMode" },
@@ -1921,16 +1745,13 @@ xplr.config.modes.builtin.relative_path_does_contain = {
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
     default = {
       help = nil,
       messages = {
         {
           RemoveNodeFilterFromInput = "IRelativePathDoesContain",
         },
-        "BufferInputFromKey",
+        "UpdateInputBufferFromKey",
         {
           AddNodeFilterFromInput = "IRelativePathDoesContain",
         },
@@ -1947,51 +1768,10 @@ xplr.config.modes.builtin.relative_path_does_not_contain = {
   extra_help = nil,
   key_bindings = {
     on_key = {
-      backspace = {
-        help = "remove last character",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesNotContain",
-          },
-          "RemoveInputBufferLastCharacter",
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesNotContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       ["ctrl-c"] = {
         help = "terminate",
         messages = { "Terminate" },
       },
-      ["ctrl-u"] = {
-        help = "remove line",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesNotContain",
-          },
-          {
-            SetInputBuffer = "",
-          },
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesNotContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
-      ["ctrl-w"] = {
-        help = "remove last word",
-        messages = {
-          {
-            RemoveNodeFilterFromInput = "IRelativePathDoesNotContain",
-          },
-          "RemoveInputBufferLastWord",
-          {
-            AddNodeFilterFromInput = "IRelativePathDoesNotContain",
-          },
-          "ExplorePwdAsync",
-        },
-      },
       enter = {
         help = "apply filter",
         messages = { "PopMode" },
@@ -2007,16 +1787,13 @@ xplr.config.modes.builtin.relative_path_does_not_contain = {
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
     default = {
       help = nil,
       messages = {
         {
           RemoveNodeFilterFromInput = "IRelativePathDoesNotContain",
         },
-        "BufferInputFromKey",
+        "UpdateInputBufferFromKey",
         {
           AddNodeFilterFromInput = "IRelativePathDoesNotContain",
         },
@@ -2180,32 +1957,18 @@ xplr.config.modes.builtin.sort = {
       ["r"] = {
         help = "by relative path",
         messages = {
-          {
-            AddNodeSorter = {
-              sorter = "ByIRelativePath",
-              reverse = false,
-            },
-          },
+          { AddNodeSorter = { sorter = "ByIRelativePath", reverse = false } },
           "ExplorePwdAsync",
         },
       },
       ["s"] = {
         help = "by size",
         messages = {
-          {
-            AddNodeSorter = {
-              sorter = "BySize",
-              reverse = false,
-            },
-          },
+          { AddNodeSorter = { sorter = "BySize", reverse = false } },
           "ExplorePwdAsync",
         },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
@@ -2264,10 +2027,6 @@ xplr.config.modes.builtin.switch_layout = {
         messages = { "PopMode" },
       },
     },
-    on_alphabet = nil,
-    on_number = nil,
-    on_special_character = nil,
-    default = nil,
   },
 }
 
