@@ -1,17 +1,29 @@
-use crate::app::Node;
 use crate::app::VERSION;
 use crate::config::Config;
 use anyhow::bail;
+use anyhow::Error;
 use anyhow::Result;
 use mlua::Lua;
 use mlua::LuaSerdeExt;
+use mlua::SerializeOptions;
 use serde::Deserialize;
+use serde::Serialize;
 use std::fs;
 
 const DEFAULT_LUA_SCRIPT: &str = include_str!("init.lua");
-const CACHE_LUA_SCRIPT: &str = include_str!("__cache__.lua");
 const UPGRADE_GUIDE_LINK: &str = "https://xplr.dev/en/upgrade-guide.html";
 
+pub fn serialize<'lua, T: Serialize + Sized>(
+    lua: &'lua mlua::Lua,
+    value: &T,
+) -> Result<mlua::Value<'lua>> {
+    lua.to_value_with(
+        value,
+        SerializeOptions::new().serialize_none_to_null(false),
+    )
+    .map_err(Error::from)
+}
+
 fn parse_version(version: &str) -> Result<(u16, u16, u16, Option<u16>)> {
     let mut configv = version.split('.');
 
@@ -57,7 +69,7 @@ pub fn init(lua: &Lua) -> Result<Config> {
     let globals = lua.globals();
 
     let lua_xplr = lua.create_table()?;
-    lua_xplr.set("config", lua.to_value(&config)?)?;
+    lua_xplr.set("config", serialize(lua, &config)?)?;
 
     let lua_xplr_fn = lua.create_table()?;
     let lua_xplr_fn_builtin = lua.create_table()?;
@@ -69,7 +81,6 @@ pub fn init(lua: &Lua) -> Result<Config> {
     globals.set("xplr", lua_xplr)?;
 
     lua.load(DEFAULT_LUA_SCRIPT).set_name("init")?.exec()?;
-    lua.load(CACHE_LUA_SCRIPT).set_name("internal")?.exec()?;
 
     let lua_xplr: mlua::Table = globals.get("xplr")?;
     let config: Config = lua.from_value(lua_xplr.get("config")?)?;
@@ -133,29 +144,6 @@ pub fn call<'lua, R: Deserialize<'lua>>(
     Ok(res)
 }
 
-/// Used to call lua functions with cache support.
-pub fn call_with_cache<'lua, R: Deserialize<'lua>>(
-    lua: &'lua Lua,
-    func: &str,
-    arg: mlua::Value<'lua>,
-) -> Result<R> {
-    let caller: mlua::Function =
-        resolve_fn(&lua.globals(), "xplr.__CACHE__.call")?;
-    let func = format!("xplr.fn.{}", func);
-    let func: mlua::Function = resolve_fn(&lua.globals(), &func)?;
-    let res: mlua::Value = caller.call((func, arg))?;
-    let res: R = lua.from_value(res)?;
-    Ok(res)
-}
-
-/// Used to cache the directory nodes.
-pub fn cache_directory_nodes(lua: &Lua, nodes: &[Node]) -> Result<()> {
-    let func = "xplr.__CACHE__.set_directory_nodes";
-    let func: mlua::Function = resolve_fn(&lua.globals(), func)?;
-    func.call(lua.to_value(nodes)?)?;
-    Ok(())
-}
-
 #[cfg(test)]
 mod tests {
 
@@ -166,24 +154,24 @@ mod tests {
         assert!(check_version(VERSION, "foo path").is_ok());
 
         // Current release if OK
-        assert!(check_version("0.16.4", "foo path").is_ok());
+        assert!(check_version("0.17.0", "foo path").is_ok());
 
         // Prev major release is ERR
         // - Not yet
 
         // Prev minor release is ERR (Change when we get to v1)
-        assert!(check_version("0.15.4", "foo path").is_err());
+        assert!(check_version("0.16.0", "foo path").is_err());
 
         // Prev bugfix release is OK
-        assert!(check_version("0.16.3", "foo path").is_ok());
+        // assert!(check_version("0.17.-1", "foo path").is_ok());
 
         // Next major release is ERR
-        assert!(check_version("1.16.4", "foo path").is_err());
+        assert!(check_version("1.17.0", "foo path").is_err());
 
         // Next minor release is ERR
-        assert!(check_version("0.17.4", "foo path").is_err());
+        assert!(check_version("0.18.0", "foo path").is_err());
 
         // Next bugfix release is ERR (Change when we get to v1)
-        assert!(check_version("0.16.5", "foo path").is_err());
+        assert!(check_version("0.17.1", "foo path").is_err());
     }
 }
