@@ -9,7 +9,6 @@ use anyhow::Result;
 use indexmap::IndexSet;
 use lazy_static::lazy_static;
 use mlua::Lua;
-use mlua::LuaSerdeExt;
 use serde::{Deserialize, Serialize};
 use std::cmp::Ordering;
 use std::collections::HashMap;
@@ -598,8 +597,7 @@ fn draw_table<B: Backend>(
                         node_type.meta,
                     );
 
-                    let cols = lua
-                        .to_value::<NodeUiMetadata>(&meta)
+                    let cols = lua::serialize::<NodeUiMetadata>(lua, &meta)
                         .map(|v| {
                             app_config
                                 .general
@@ -737,10 +735,14 @@ fn draw_help_menu<B: Backend>(
         .into_iter()
         .map(|l| match l {
             HelpMenuLine::Paragraph(p) => Row::new([Cell::from(p)].to_vec()),
-            HelpMenuLine::KeyMap(k, remaps, h) => Row::new(
-                [Cell::from(k), Cell::from(remaps.join("|")), Cell::from(h)]
-                    .to_vec(),
-            ),
+            HelpMenuLine::KeyMap(k, remaps, h) => Row::new({
+                if app.config.general.hide_remaps_in_help_menu {
+                    [Cell::from(k), Cell::from(h)].to_vec()
+                } else {
+                    [Cell::from(k), Cell::from(remaps.join("|")), Cell::from(h)]
+                        .to_vec()
+                }
+            }),
         })
         .collect::<Vec<Row>>();
 
@@ -749,11 +751,15 @@ fn draw_help_menu<B: Backend>(
             config,
             format!(" Help [{}{}] ", &app.mode.name, read_only_indicator(app)),
         ))
-        .widths(&[
-            TuiConstraint::Percentage(20),
-            TuiConstraint::Percentage(20),
-            TuiConstraint::Percentage(60),
-        ]);
+        .widths(if app.config.general.hide_remaps_in_help_menu {
+            &[TuiConstraint::Percentage(20), TuiConstraint::Percentage(80)]
+        } else {
+            &[
+                TuiConstraint::Percentage(20),
+                TuiConstraint::Percentage(20),
+                TuiConstraint::Percentage(60),
+            ]
+        });
     f.render_widget(help_menu, layout_size);
 }
 
@@ -1026,15 +1032,14 @@ pub fn draw_custom_content<B: Backend>(
 
         ContentBody::DynamicParagraph { render } => {
             let ctx = ContentRendererArg {
-                app: app.to_lua_arg(),
+                app: app.to_lua_ctx_light(),
                 layout_size: layout_size.into(),
                 screen_size: screen_size.into(),
             };
 
-            let render = lua
-                .to_value(&ctx)
+            let render = lua::serialize(lua, &ctx)
                 .map(|arg| {
-                    lua::call_with_cache(lua, &render, arg)
+                    lua::call(lua, &render, arg)
                         .unwrap_or_else(|e| format!("{:?}", e))
                 })
                 .unwrap_or_else(|e| e.to_string());
@@ -1068,15 +1073,14 @@ pub fn draw_custom_content<B: Backend>(
 
         ContentBody::DynamicList { render } => {
             let ctx = ContentRendererArg {
-                app: app.to_lua_arg(),
+                app: app.to_lua_ctx_light(),
                 layout_size: layout_size.into(),
                 screen_size: screen_size.into(),
             };
 
-            let items = lua
-                .to_value(&ctx)
+            let items = lua::serialize(lua, &ctx)
                 .map(|arg| {
-                    lua::call_with_cache(lua, &render, arg)
+                    lua::call(lua, &render, arg)
                         .unwrap_or_else(|e| vec![format!("{:?}", e)])
                 })
                 .unwrap_or_else(|e| vec![e.to_string()])
@@ -1138,15 +1142,14 @@ pub fn draw_custom_content<B: Backend>(
             render,
         } => {
             let ctx = ContentRendererArg {
-                app: app.to_lua_arg(),
+                app: app.to_lua_ctx_light(),
                 layout_size: layout_size.into(),
                 screen_size: screen_size.into(),
             };
 
-            let rows = lua
-                .to_value(&ctx)
+            let rows = lua::serialize(lua, &ctx)
                 .map(|arg| {
-                    lua::call_with_cache(lua, &render, arg)
+                    lua::call(lua, &render, arg)
                         .unwrap_or_else(|e| vec![vec![format!("{:?}", e)]])
                 })
                 .unwrap_or_else(|e| vec![vec![e.to_string()]])
@@ -1205,7 +1208,7 @@ impl From<TuiRect> for Rect {
 
 #[derive(Debug, Clone, Serialize)]
 pub struct ContentRendererArg {
-    app: app::CallLuaArg,
+    app: app::LuaContextLight,
     screen_size: Rect,
     layout_size: Rect,
 }
